@@ -67,7 +67,7 @@
 #' automatically determined for the \sQuote{\code{plfit}} implementation. This
 #' argument makes it possible to fit only the tail of the distribution.
 #' @param start Numeric scalar. The initial value of the exponent for the
-#' minimizing function, for the \sQuote{\code{R.mle}} implementation. Ususally
+#' minimizing function, for the \sQuote{\code{R.mle}} implementation. Usually
 #' it is safe to leave this untouched.
 #' @param force.continuous Logical scalar. Whether to force a continuous
 #' distribution for the \sQuote{\code{plfit}} implementation, even if the
@@ -177,10 +177,9 @@ power.law.fit.new <- function(data, xmin=-1, force.continuous=FALSE) {
   xmin <- as.numeric(xmin)
   force.continuous <- as.logical(force.continuous)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
+  on.exit( .Call(C_R_igraph_finalizer) )
   # Function call
-  res <- .Call("R_igraph_power_law_fit", data, xmin, force.continuous,
-        PACKAGE="igraph")
+  res <- .Call(C_R_igraph_power_law_fit, data, xmin, force.continuous)
 
   res
 }
