@@ -21,9 +21,10 @@
 ##
 ## -----------------------------------------------------------------
 
-#' Generate scale-free graphs according to the Barabasi-Albert model
+#' Generate random graphs using preferential attachment
 #' 
-#' The BA-model is a very simple stochastic algorithm for building a graph.
+#' Preferential attachment is a family of simple stochastic algorithms for building
+#' a graph. Variants include the Barabási-Abert model and the Price model.
 #' 
 #' This is a simple stochastic algorithm to generate a graph. It is a discrete
 #' time step model and in each time step a single vertex is added.
@@ -87,7 +88,7 @@
 #' one, or \code{zero.appeal} was not one.  \code{bag} is the algorithm that
 #' was previously (before version 0.6) used if \code{power} was one and
 #' \code{zero.appeal} was one as well. It works by putting the ids of the
-#' vertices into a bag (mutliset, really), exactly as many times as their
+#' vertices into a bag (multiset, really), exactly as many times as their
 #' (in-)degree, plus once more. Then the required number of cited vertices are
 #' drawn from the bag, with replacement. This method might generate multiple
 #' edges. It only works if \code{power} and \code{zero.appeal} are equal one.
@@ -102,6 +103,9 @@
 #' @seealso \code{\link{sample_gnp}}
 #' @references Barabasi, A.-L. and Albert R. 1999. Emergence of scaling in
 #' random networks \emph{Science}, 286 509--512.
+#' 
+#' de Solla Price, D. J. 1965. Networks of Scientific Papers \emph{Science},
+#' 149 510--515.
 #' @export
 #' @keywords graphs
 #' @examples
@@ -132,9 +136,6 @@ sample_pa <- function(n, power=1, m=NULL, out.dist=NULL, out.seq=NULL,
   if (!is.null(m) && m==0) {
     warning("`m' is zero, graph will be empty")
   }
-  if (power < 0) {
-    warning("`power' is negative")
-  }
   
   if (is.null(m) && is.null(out.dist) && is.null(out.seq)) {
     m <- 1
@@ -224,7 +225,7 @@ sample_gnp <- function(n, p, directed = FALSE, loops = FALSE) {
                as.numeric(p), as.logical(directed), as.logical(loops))
 
   if (igraph_opt("add.params")) {
-    res$name <- sprintf("Erdos renyi (%s) graph", type)
+    res$name <- sprintf("Erdos-Renyi (%s) graph", type)
     res$type <- type
     res$loops <- loops
     res$p <- p
@@ -233,7 +234,7 @@ sample_gnp <- function(n, p, directed = FALSE, loops = FALSE) {
 }
 
 #' @rdname sample_gnp
-#' @param ... Passed to \code{sample_app}.
+#' @param ... Passed to \code{sample_gnp}.
 #' @export
 
 gnp <- function(...) constructor_spec(sample_gnp, ...)
@@ -279,7 +280,7 @@ sample_gnm <- function(n, m, directed = FALSE, loops = FALSE) {
                as.numeric(m), as.logical(directed), as.logical(loops))
 
   if (igraph_opt("add.params")) {
-    res$name <- sprintf("Erdos renyi (%s) graph", type)
+    res$name <- sprintf("Erdos-Renyi (%s) graph", type)
     res$type <- type
     res$loops <- loops
     res$m <- m
@@ -288,7 +289,7 @@ sample_gnm <- function(n, m, directed = FALSE, loops = FALSE) {
 }
 
 #' @rdname sample_gnm
-#' @param ... Passed to \code{sample_app}.
+#' @param ... Passed to \code{sample_gnm}.
 #' @export
 
 gnm <- function(...) constructor_spec(sample_gnm, ...)
@@ -326,7 +327,6 @@ gnm <- function(...) constructor_spec(sample_gnm, ...)
 #' @param directed Logical, whether the graph will be directed, defaults to
 #' FALSE.
 #' @param loops Logical, whether to add loop edges, defaults to FALSE.
-#' @param \dots Additional arguments, ignored.
 #' @return A graph object.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @seealso \code{\link{sample_pa}}
@@ -340,7 +340,7 @@ gnm <- function(...) constructor_spec(sample_gnm, ...)
 #' degree_distribution(g)
 #' 
 erdos.renyi.game <- function(n, p.or.m, type=c("gnp", "gnm"),
-                             directed=FALSE, loops=FALSE, ...) {
+                             directed=FALSE, loops=FALSE) {
 
   type <- igraph.match.arg(type)
   type1 <- switch(type, "gnp"=0, "gnm"=1)
@@ -350,7 +350,7 @@ erdos.renyi.game <- function(n, p.or.m, type=c("gnp", "gnm"),
                as.numeric(p.or.m), as.logical(directed), as.logical(loops))
 
   if (igraph_opt("add.params")) {
-    res$name <- sprintf("Erdos renyi (%s) graph", type)
+    res$name <- sprintf("Erdos-Renyi (%s) graph", type)
     res$type <- type
     res$loops <- loops
     if (type=="gnp") { res$p <- p.or.m }
@@ -367,8 +367,8 @@ random.graph.game <- erdos.renyi.game
 
 #' Generate random graphs with a given degree sequence
 #' 
-#' It is often useful to create a graph with given vertex degrees. This is
-#' exactly what \code{sample_degseq} does.
+#' It is often useful to create a graph with given vertex degrees. This function
+#' creates such a graph in a randomized manner.
 #' 
 #' The \dQuote{simple} method connects the out-stubs of the edges (undirected
 #' graphs) or the out-stubs and in-stubs (directed graphs) together. This way
@@ -385,6 +385,11 @@ random.graph.game <- erdos.renyi.game
 #' fast and it will eventually succeed if the provided degree sequence is
 #' graphical, but there is no upper bound on the number of iterations.
 #' 
+#' The \dQuote{simple.no.multiple.uniform} method is a variant of
+#' \dQuote{simple.no.multiple} with the added benefit of sampling uniformly
+#' from the set of all possible simple graphs with the given degree sequence.
+#' Ensuring uniformity has some performance implications, though.
+#'
 #' The \dQuote{vl} method is a more sophisticated generator. The algorithm and
 #' the implementation was done by Fabien Viger and Matthieu Latapy. This
 #' generator always generates undirected, connected simple graphs, it is an
@@ -393,7 +398,7 @@ random.graph.game <- erdos.renyi.game
 #' with the given degree sequence (if this is possible at all). Then some
 #' rewiring is done to make the graph connected. Finally a Monte-Carlo
 #' algorithm is used to randomize the graph. The \dQuote{vl} samples from the
-#' undirected, connected simple graphs unformly.
+#' undirected, connected simple graphs uniformly.
 #'
 #' @aliases degree.sequence.game
 #' @param out.deg Numeric vector, the sequence of degrees (for undirected
@@ -408,7 +413,8 @@ random.graph.game <- erdos.renyi.game
 #' @return The new graph object.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @seealso \code{\link{sample_gnp}}, \code{\link{sample_pa}},
-#' \code{\link{simplify}} to get rid of the multiple and/or loops edges.
+#' \code{\link{simplify}} to get rid of the multiple and/or loops edges,
+#' \code{\link{realize_degseq}} for a deterministic variant.
 #' @export
 #' @keywords graphs
 #' @examples
@@ -441,11 +447,10 @@ random.graph.game <- erdos.renyi.game
 #' all(degree(g5) == degs)
 
 sample_degseq <- function(out.deg, in.deg=NULL,
-                                 method=c("simple", "vl",
-                                   "simple.no.multiple")) {
+                          method=c("simple", "vl", "simple.no.multiple", "simple.no.multiple.uniform")) {
 
   method <- igraph.match.arg(method)
-  method1 <- switch(method, "simple"=0, "vl"=1, "simple.no.multiple"=2)
+  method1 <- switch(method, "simple"=0, "vl"=1, "simple.no.multiple"=2, "simple.no.multiple.uniform"=3)
   if (!is.null(in.deg)) { in.deg <- as.numeric(in.deg) }
 
   on.exit( .Call(C_R_igraph_finalizer) )
@@ -459,11 +464,14 @@ sample_degseq <- function(out.deg, in.deg=NULL,
 }
 
 #' @rdname sample_degseq
-#' @param ... Passed to \code{sample_degree}.
+#' @param deterministic  Whether the construction should be deterministic
+#' @param ... Passed to \code{realize_degseq} if \sQuote{deterministic} is true,
+#' or to \code{sample_degseq} otherwise.
 #' @export
 
-degseq <- function(...) constructor_spec(sample_degseq, ...)
-
+degseq <- function(..., deterministic=FALSE) constructor_spec(
+  if (deterministic) realize_degseq else sample_degseq, ...
+)
 
 ## -----------------------------------------------------------------
 
@@ -506,7 +514,7 @@ sample_growing <- function(n, m=1, directed=TRUE, citation=FALSE) {
 }
 
 #' @rdname sample_growing
-#' @param ... Passed to \code{sample_app}.
+#' @param ... Passed to \code{sample_growing}.
 #' @export
 
 growing <- function(...) constructor_spec(sample_growing, ...)
@@ -525,9 +533,8 @@ growing <- function(...) constructor_spec(sample_growing, ...)
 #' network containing a single vertex (and no edges) in the first time step.
 #' Then in each time step (starting with the second) a new vertex is added and
 #' it initiates a number of edges to the old vertices in the network. The
-#' probability that an old vertex is connected to is proportional to \deqn{P[i]
-#' \sim (c\cdot k_i^\alpha+a)(d\cdot l_i^\beta+b)\cdot }{% P[i] ~ (c k[i]^alpha
-#' + a) (d l[i]^beta + a)}
+#' probability that an old vertex is connected to is proportional to
+#' \deqn{P[i] \sim (c\cdot k_i^\alpha+a)(d\cdot l_i^\beta+b)}.
 #' 
 #' Here \eqn{k_i}{k[i]} is the in-degree of vertex \eqn{i} in the current time
 #' step and \eqn{l_i}{l[i]} is the age of vertex \eqn{i}. The age is simply
@@ -557,7 +564,7 @@ growing <- function(...) constructor_spec(sample_growing, ...)
 #' 
 #' By default a directed graph is generated, but it \code{directed} is set to
 #' \code{FALSE} then an undirected is created. Even if an undirected graph is
-#' generaed \eqn{k_i}{k[i]} denotes only the adjacent edges not initiated by
+#' generated \eqn{k_i}{k[i]} denotes only the adjacent edges not initiated by
 #' the vertex itself except if \code{out.pref} is set to \code{TRUE}.
 #' 
 #' If the \code{time.window} argument is given (and not NULL) then
@@ -568,7 +575,7 @@ growing <- function(...) constructor_spec(sample_growing, ...)
 #' 
 #' @aliases sample_pa_age aging.prefatt.game aging.barabasi.game aging.ba.game
 #' @param n The number of vertices in the graph.
-#' @param pa.exp The preferantial attachment exponent, see the details below.
+#' @param pa.exp The preferential attachment exponent, see the details below.
 #' @param aging.exp The exponent of the aging, usually a non-positive number,
 #' see details below.
 #' @param m The number of edges each new vertex creates (except the very first
@@ -641,9 +648,6 @@ sample_pa_age <- function(n, pa.exp, aging.exp, m=NULL, aging.bin=300,
   if (!is.null(m) && m==0) {
     warning("`m' is zero, graph will be empty")
   }
-  if (pa.exp < 0) {
-    warning("preferential attachment is negative")
-  }
   if (aging.exp > 0) {
     warning("aging exponent is positive")
   }
@@ -744,8 +748,8 @@ pa_age <- function(...) constructor_spec(sample_pa_age, ...)
 #' @examples
 #' 
 #' # two types of vertices, they like only themselves
-#' g1 <- sample_traits_callaway(1000, 2, pref.matrix=matrix( c(1,0,0,1), nc=2))
-#' g2 <- sample_traits(1000, 2, k=2, pref.matrix=matrix( c(1,0,0,1), nc=2))
+#' g1 <- sample_traits_callaway(1000, 2, pref.matrix=matrix( c(1,0,0,1), ncol=2))
+#' g2 <- sample_traits(1000, 2, k=2, pref.matrix=matrix( c(1,0,0,1), ncol=2))
 
 sample_traits_callaway <- function(nodes, types, edge.per.step=1,
                                  type.dist=rep(1, types),
@@ -867,7 +871,7 @@ grg <- function(...) constructor_spec(sample_grg, ...)
 #' \code{sample_pref} the probability that two vertices will be connected
 #' depends on their type and is given by the \sQuote{pref.matrix} argument.
 #' This matrix should be symmetric to make sense but this is not checked. The
-#' distribution of the different vertes types is given by the
+#' distribution of the different vertex types is given by the
 #' \sQuote{type.dist} vector.
 #' 
 #' For \code{sample_asym_pref} each vertex has an in-type and an
@@ -877,6 +881,10 @@ grg <- function(...) constructor_spec(sample_grg, ...)
 #' asymmetric. The joint distribution for the in- and out-types is given in the
 #' \sQuote{type.dist.matrix} argument.
 #' 
+#' The types of the generated vertices can be retrieved from the
+#' \code{type} vertex attribute for \code{sample_pref} and from the
+#' \code{intype} and \code{outtype} vertex attribute for \code{sample_asym_pref}.
+#'
 #' @aliases sample_pref sample_asym_pref preference.game asymmetric.preference.game
 #' @param nodes The number of vertices in the graphs.
 #' @param types The number of different vertex types.
@@ -901,11 +909,11 @@ grg <- function(...) constructor_spec(sample_grg, ...)
 #' @keywords graphs
 #' @examples
 #' 
-#' pf <- matrix( c(1, 0, 0, 1), nr=2)
+#' pf <- matrix( c(1, 0, 0, 1), nrow=2)
 #' g <- sample_pref(20, 2, pref.matrix=pf)
 #' \dontrun{tkplot(g, layout=layout_with_fr)}
 #' 
-#' pf <- matrix( c(0, 1, 0, 0), nr=2)
+#' pf <- matrix( c(0, 1, 0, 0), nrow=2)
 #' g <- sample_asym_pref(20, 2, pref.matrix=pf)
 #' \dontrun{tkplot(g, layout=layout_in_circle)}
 #' 
@@ -918,9 +926,13 @@ sample_pref <- function(nodes, types, type.dist=rep(1, types),
     stop("Invalid size for preference matrix")
   }
   
+  if (!directed && !isSymmetric(pref.matrix)) {
+    warning("Undirected graphs require symmetric preference matrices, symmetrizing matrix. igraph 1.4.0 will reject non-symmetric matrices for undirected graphs.")
+    pref.matrix <- Matrix::forceSymmetric((pref.matrix + t(pref.matrix)) / 2)
+  }
+
   on.exit( .Call(C_R_igraph_finalizer) )
-  res <- .Call(C_R_igraph_preference_game, as.double(nodes),
-               as.double(types),
+  res <- .Call(C_R_igraph_preference_game, as.integer(nodes), as.integer(types),
                as.double(type.dist), as.logical(fixed.sizes),
                matrix(as.double(pref.matrix), types, types),
                as.logical(directed), as.logical(loops))
@@ -960,19 +972,21 @@ sample_asym_pref <- function(nodes, types,
   
   on.exit( .Call(C_R_igraph_finalizer) )
   res <- .Call(C_R_igraph_asymmetric_preference_game,
-               as.double(nodes), as.double(types),
+               as.integer(nodes), as.integer(types), as.integer(types),
                matrix(as.double(type.dist.matrix), types, types),
                matrix(as.double(pref.matrix), types, types),
                as.logical(loops))
+  V(res[[1]])$outtype <- res[[2]] + 1
+  V(res[[1]])$intype  <- res[[3]] + 1
   if (igraph_opt("add.params")) {
-    res$name <- "Asymmetric preference random graph"
-    res$types <- types
-    res$type.dist.matrix <- type.dist.matrix
-    res$pref.matrix <- pref.matrix
-    res$loops <- loops
+    res[[1]]$name <- "Asymmetric preference random graph"
+    res[[1]]$types <- types
+    res[[1]]$type.dist.matrix <- type.dist.matrix
+    res[[1]]$pref.matrix <- pref.matrix
+    res[[1]]$loops <- loops
   }
 
-  res
+  res[[1]]
 }
 
 #' @rdname sample_pref
@@ -983,6 +997,9 @@ asym_pref <- function(...) constructor_spec(sample_asym_pref, ...)
 ## -----------------------------------------------------------------
 
 
+#' @rdname ego
+#' @export
+
 connect <- function(graph, order, mode=c("all", "out", "in", "total")) {
   if (!is_igraph(graph)) {
     stop("Not a graph object")
@@ -1067,7 +1084,7 @@ smallworld <- function(...) constructor_spec(sample_smallworld, ...)
 #' graph is growing.
 #'
 #' \code{sample_cit_types} is similarly a growing stochastic block model,
-#' but the probability of an edge depends on the (potentiall) cited
+#' but the probability of an edge depends on the (potentially) cited
 #' vertex only.
 #' 
 #' @aliases cited.type.game sample_cit_types citing.cited.type.game
@@ -1166,21 +1183,21 @@ cit_cit_types <- function(...) constructor_spec(sample_cit_cit_types, ...)
 #' 
 #' Generate bipartite graphs using the Erdos-Renyi model
 #' 
-#' Similarly to unipartite (one-mode) networks, we can define the $G(n,p)$, and
-#' $G(n,m)$ graph classes for bipartite graphs, via their generating process.
-#' In $G(n,p)$ every possible edge between top and bottom vertices is realized
-#' with probablity $p$, independently of the rest of the edges. In $G(n,m)$, we
-#' uniformly choose $m$ edges to realize.
+#' Similarly to unipartite (one-mode) networks, we can define the \eqn{G(n,p)}, and
+#' \eqn{G(n,m)} graph classes for bipartite graphs, via their generating process.
+#' In \eqn{G(n,p)} every possible edge between top and bottom vertices is realized
+#' with probability \eqn{p}, independently of the rest of the edges. In \eqn{G(n,m)}, we
+#' uniformly choose \eqn{m} edges to realize.
 #'
 #' @aliases bipartite.random.game
 #' @param n1 Integer scalar, the number of bottom vertices.
 #' @param n2 Integer scalar, the number of top vertices.
 #' @param type Character scalar, the type of the graph, \sQuote{gnp} creates a
-#' $G(n,p)$ graph, \sQuote{gnm} creates a $G(n,m)$ graph. See details below.
-#' @param p Real scalar, connection probability for $G(n,p)$ graphs. Should not
-#' be given for $G(n,m)$ graphs.
-#' @param m Integer scalar, the number of edges for $G(n,p)$ graphs. Should not
-#' be given for $G(n,p)$ graphs.
+#' \eqn{G(n,p)} graph, \sQuote{gnm} creates a \eqn{G(n,m)} graph. See details below.
+#' @param p Real scalar, connection probability for \eqn{G(n,p)} graphs. Should not
+#' be given for \eqn{G(n,m)} graphs.
+#' @param m Integer scalar, the number of edges for \eqn{G(n,p)} graphs. Should not
+#' be given for \eqn{G(n,p)} graphs.
 #' @param directed Logical scalar, whether to create a directed graph. See also
 #' the \code{mode} argument.
 #' @param mode Character scalar, specifies how to direct the edges in directed
@@ -1263,6 +1280,8 @@ bipartite <- function(...) constructor_spec(sample_bipartite, ...)
 #' This function samples graphs from a stochastic block model by (doing the
 #' equivalent of) Bernoulli trials for each potential edge with the
 #' probabilities given by the Bernoulli rate matrix, \code{pref.matrix}.
+#' The order of the vertices in the generated graph corresponds to the 
+#' \code{block.sizes} argument. 
 #' 
 #' @aliases sample_sbm sbm.game sbm
 #' @param n Number of vertices in the graph.
@@ -1275,7 +1294,6 @@ bipartite <- function(...) constructor_spec(sample_bipartite, ...)
 #' group. The sum of the vector must match the number of vertices.
 #' @param directed Logical scalar, whether to generate a directed graph.
 #' @param loops Logical scalar, whether self-loops are allowed in the graph.
-#' @param \dots Passed to \code{sample_sbm}.
 #' @return An igraph graph.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @seealso \code{\link{sample_gnp}}, \code{\link{sample_gnm}}
@@ -1293,6 +1311,7 @@ bipartite <- function(...) constructor_spec(sample_bipartite, ...)
 sample_sbm <- sample_sbm
 
 #' @rdname sample_sbm
+#' @param ... Passed to \code{sample_sbm}.
 #' @export
 
 sbm <- function(...) constructor_spec(sample_sbm, ...)
@@ -1321,7 +1340,6 @@ sbm <- function(...) constructor_spec(sample_sbm, ...)
 #' differ in different blocks.
 #' @param p Numeric scalar, the Bernoulli rate of connections between vertices
 #' in different blocks.
-#' @param \dots Passed to \code{sample_hierarchical_sbm}.
 #' @return An igraph graph.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @seealso \code{\link{sbm.game}}
@@ -1346,7 +1364,7 @@ sample_hierarchical_sbm <- function(n, m, rho, C, p) {
   commonlen <- unique(c(mlen, rholen, Clen))
 
   if (length(commonlen) == 1 && commonlen == 1) {
-    hsbm.1.game(n, m, rho, C, p)
+    hsbm_1_game(n, m, rho, C, p)
   } else {
     commonlen <- setdiff(commonlen, 1)
     if (length(commonlen) != 1) {
@@ -1363,11 +1381,12 @@ sample_hierarchical_sbm <- function(n, m, rho, C, p) {
     } else {
       rep(list(C), length.out=commonlen)
     }
-    hsbm.list.game(n, m, rho, C, p)
+    hsbm_list_game(n, m, rho, C, p)
   }  
 }
 
 #' @rdname sample_hierarchical_sbm
+#' @param ... Passed to \code{sample_hierarchical_sbm}.
 #' @export
 
 hierarchical_sbm <- function(...)
@@ -1391,7 +1410,6 @@ hierarchical_sbm <- function(...)
 #' column.
 #' @param directed A logical scalar, TRUE if the generated graph should be
 #' directed.
-#' @param \dots Passed to \code{sample_dot_product}.
 #' @return An igraph graph object which is the generated random dot product
 #' graph.
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
@@ -1417,8 +1435,9 @@ hierarchical_sbm <- function(...)
 
 sample_dot_product <- sample_dot_product
 
-#' @export
 #' @rdname sample_dot_product
+#' @param ... Passed to \code{sample_dot_product}.
+#' @export
 
 dot_product <- function(...) constructor_spec(sample_dot_product, ...)
 
@@ -1667,8 +1686,8 @@ sample_fitness_pl <- sample_fitness_pl
 #' g <- sample_forestfire(10000, fw.prob=0.37, bw.factor=0.32/0.37)
 #' dd1 <- degree_distribution(g, mode="in")
 #' dd2 <- degree_distribution(g, mode="out")
-#' plot(seq(along=dd1)-1, dd1, log="xy")
-#' points(seq(along=dd2)-1, dd2, col=2, pch=2)
+#' plot(seq(along.with=dd1)-1, dd1, log="xy")
+#' points(seq(along.with=dd2)-1, dd2, col=2, pch=2)
 
 sample_forestfire <- sample_forestfire
 
@@ -1683,10 +1702,13 @@ sample_forestfire <- sample_forestfire
 #' 
 #' @param old.graph The original graph.
 #' @param corr A scalar in the unit interval, the target Pearson
-#' correlation between the adjacency matrices of the original the generated
+#' correlation between the adjacency matrices of the original and the generated
 #' graph (the adjacency matrix being used as a vector).
 #' @param p A numeric scalar, the probability of an edge between two
-#' vertices, it must in the open (0,1) interval.
+#' vertices, it must in the open (0,1) interval. The default is the empirical
+#' edge density of the graph. If you are resampling an Erdos-Renyi graph and
+#' you know the original edge probability of the Erdos-Renyi model, you should
+#' supply that explicitly.
 #' @param permutation A numeric vector, a permutation vector that is
 #' applied on the vertices of the first graph, to get the second graph.  If
 #' \code{NULL}, the vertices are not permuted.
