@@ -123,10 +123,9 @@ fit_hrg <- function(graph, hrg=NULL, start=FALSE, steps=0) {
   start <- as.logical(start)
   steps <- as.integer(steps)
   
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
+  on.exit( .Call(C_R_igraph_finalizer) )
   # Function call
-  res <- .Call("R_igraph_hrg_fit", graph, hrg, start, steps,
-               PACKAGE="igraph")
+  res <- .Call(C_R_igraph_hrg_fit, graph, hrg, start, steps)
   
   if (igraph_opt("add.vertex.names") && is_named(graph)) {
     res$names <- V(graph)$name
@@ -164,7 +163,7 @@ fit_hrg <- function(graph, hrg=NULL, start=FALSE, steps=0) {
 #'     vertex ids (from 0) refer to the original vertices of the graph, the
 #'     other ids refer to vertex groups.}
 #'   \item{weights}{Numeric vector, counts the number of times a given tree
-#'     split occured in the generated network samples, for each internal
+#'     split occurred in the generated network samples, for each internal
 #'     vertices. The order is the same as in the \code{parents} vector.}
 
 #' @include auto.R
@@ -295,10 +294,10 @@ predict_edges <- function(graph, hrg=NULL, start=FALSE, num.samples=10000,
   num.samples <- as.integer(num.samples)
   num.bins <- as.integer(num.bins)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
+  on.exit( .Call(C_R_igraph_finalizer) )
   # Function call
-  res <- .Call("R_igraph_hrg_predict", graph, hrg, start, num.samples,
-               num.bins, PACKAGE="igraph")
+  res <- .Call(C_R_igraph_hrg_predict, graph, hrg, start, num.samples,
+               num.bins)
   res$edges <- matrix(res$edges, ncol=2, byrow=TRUE)
   class(res$hrg) <- "igraphHRG"
   res
@@ -308,7 +307,7 @@ predict_edges <- function(graph, hrg=NULL, start=FALSE, num.samples=10000,
 
 #' Conversion to igraph
 #' 
-#' These fucntions convert various objects to igraph graphs.
+#' These functions convert various objects to igraph graphs.
 #' 
 #' You can use \code{as.igraph} to convert various objects to igraph graphs.
 #' Right now the following objects are supported: \itemize{ \item codeigraphHRG
@@ -478,8 +477,7 @@ as.hclust.igraphHRG <- function(x, ...) {
   hcass <- .C("igraphhcass2", n=as.integer(n),
               ia=as.integer(mergeInto[,1]),
               ib=as.integer(mergeInto[,2]),
-              order=integer(n), iia=integer(n), iib=integer(n),
-              PACKAGE="igraph")
+              order=integer(n), iia=integer(n), iib=integer(n))
 
   mynames <- if (is.null(x$names)) 1:n else x$names
   res <- list(merge=merge, height=1:nrow(merge), order=hcass$order,
@@ -490,6 +488,7 @@ as.hclust.igraphHRG <- function(x, ...) {
 }
 
 #' @method as_phylo igraphHRG
+#' @importFrom stats reorder
 
 as_phylo.igraphHRG <- function(x, ...) {
 
@@ -547,7 +546,7 @@ as_phylo.igraphHRG <- function(x, ...) {
 #'     the dendrogram. The dendrogram is cut into exactly \code{rect}
 #'     groups and they are marked via the \code{rect.hclust} command. Set
 #'     this to zero if you don't want to mark any groups.
-#'   \item \code{colbar} The colors of the rectanges that mark the
+#'   \item \code{colbar} The colors of the rectangles that mark the
 #'     vertex groups via the \code{rect} argument.
 #'   \item \code{hang} Where to put the leaf nodes, this corresponds to the
 #'     \code{hang} argument of \code{plot.hclust}.
@@ -603,6 +602,10 @@ plot_dendrogram.igraphHRG <- function(x, mode=igraph_opt("dend.plot.type"), ...)
   }
 }
 
+#' @importFrom graphics plot
+#' @importFrom grDevices rainbow
+#' @importFrom stats rect.hclust
+
 hrgPlotHclust <- function(x, rect=0, colbar=rainbow(rect), hang=.01,
                           ann=FALSE, main="", sub="", xlab="", ylab="",
                           ...) {
@@ -615,15 +618,20 @@ hrgPlotHclust <- function(x, rect=0, colbar=rainbow(rect), hang=.01,
   invisible(ret)
 }
 
+#' @importFrom graphics plot
+
 hrgPlotDendrogram <- function(x, ...) {
   plot(as.dendrogram(x), ...)
 }
 
+#' @importFrom graphics plot
+#' @importFrom grDevices rainbow
+
 hrgPlotPhylo <- function(x, colbar=rainbow(11, start=.7, end=.1),
                          edge.color=NULL, use.edge.length=FALSE, ...) {
   vc <- length(x$left)+1
   phy <- as_phylo(x)
-  br <- seq(0,1,length=length(colbar)) ; br[1] <- -1
+  br <- seq(0,1,length.out=length(colbar)) ; br[1] <- -1
   cc <- as.integer(cut(x$prob[phy$edge[,1] - vc], breaks=br))
   if (is.null(edge.color)) { edge.color <- colbar[cc] }
   plot(phy, edge.color=edge.color, use.edge.length=use.edge.length, ...)
