@@ -44,7 +44,7 @@
 # - G[1,-1]     negative indices work
 #
 # - G[[1,]]     adjacent vertices of 1
-# - G[[,1]]     adjacent predessors of 1
+# - G[[,1]]     adjacent predecessors of 1
 # - G[[degree(G),]]
 #               logical vectors work
 # - G[[-1,]]    negative indices work
@@ -196,13 +196,29 @@
     }
     res
   } else if (missing(i) && missing(j)) {
-    as_adj(x, sparse=sparse, attr=attr, edges=edges)
+    if (missing(edges)) {
+      as_adj(x, sparse=sparse, attr=attr)
+    } else {
+      as_adj(x, sparse=sparse, attr=attr, edges=edges)
+    }
   } else if (missing(j)) {
-    as_adj(x, sparse=sparse, attr=attr, edges=edges)[i,,drop=drop]
+    if (missing(edges)) {
+      as_adj(x, sparse=sparse, attr=attr)[i,,drop=drop]
+    } else {
+      as_adj(x, sparse=sparse, attr=attr, edges=edges)[i,,drop=drop]
+    }
   } else if (missing(i)) {
-    as_adj(x, sparse=sparse, attr=attr, edges=edges)[,j,drop=drop]
+    if (missing(edges)) {
+      as_adj(x, sparse=sparse, attr=attr)[,j,drop=drop]
+    } else {
+      as_adj(x, sparse=sparse, attr=attr, edges=edges)[,j,drop=drop]
+    }
   } else {
-    as_adj(x, sparse=sparse, attr=attr, edges=edges)[i,j,drop=drop]
+    if (missing(edges)) {
+      as_adj(x, sparse=sparse, attr=attr)[i,j,drop=drop]
+    } else {
+      as_adj(x, sparse=sparse, attr=attr, edges=edges)[i,j,drop=drop]
+    }
   }
 }
 
@@ -215,7 +231,7 @@
 #'   \item Querying the adjacent vertices for one or more
 #'     vertices: \preformatted{  graph[[1:3,]]
 #' graph[[,1:3]]}
-#'     The first form gives the successors, the second the predessors
+#'     The first form gives the successors, the second the predecessors
 #'     or the 1:3 vertices. (For undirected graphs they are equivalent.)
 #'   \item Querying the incident edges for one or more vertices,
 #'     if the \code{edges} argument is set to
@@ -293,7 +309,7 @@
   } else {
     if (!edges) {
       mode <- if (directed) "out" else "all"
-      lapply(adjacent_vertices(x, i, mode = mode), intersection, V(x)[j])
+      lapply(adjacent_vertices(x, i, mode = mode), intersection, V(x)[.env$j])
     } else {
       i <- as.igraph.vs(x, i)
       j <- as.igraph.vs(x, j)
@@ -310,6 +326,14 @@
   }
 }
 
+#' @method length igraph
+#' @family structural queries
+#' @export
+
+length.igraph <- function(x) {
+  vcount(x)
+}
+
 #' @method [<- igraph
 #' @family functions for manipulating graph structure
 #' @export
