@@ -147,7 +147,10 @@ add_vertices <- function(graph, nv, ..., attr=list()) {
 #' Delete edges from a graph
 #'
 #' @param graph The input graph.
-#' @param edges The edges to remove, specified as an edge sequence.
+#' @param edges The edges to remove, specified as an edge sequence. Typically
+#' this is either a numeric vector containing edge IDs, or a character vector
+#' containing the IDs or names of the source and target vertices, separated by
+#' \code{|}
 #' @return The graph, with the edges removed.
 #'
 #' @aliases delete.edges
@@ -162,6 +165,10 @@ add_vertices <- function(graph, nv, ..., attr=list()) {
 #' g <- make_ring(10) %>%
 #'   delete_edges("10|1")
 #' g
+#'
+#' g <- make_ring(5)
+#' g <- delete_edges(g, get.edge.ids(g, c(1,5, 4,5)))
+#' g
 
 delete_edges <- function(graph, edges) {
   if (!is_igraph(graph)) {
@@ -206,7 +213,7 @@ delete_vertices <- function(graph, v) {
 
 #' The size of the graph (number of edges)
 #'
-#' \code{ecount} of an alias of this function.
+#' \code{ecount} is an alias of this function.
 #' 
 #' @param graph The graph.
 #' @return Numeric scalar, the number of edges.
@@ -218,6 +225,7 @@ delete_vertices <- function(graph, v) {
 #' @examples
 #' g <- sample_gnp(100, 2/100)
 #' gsize(g)
+#' ecount(g)
 #' 
 #' # Number of edges in a G(n,p) graph
 #' replicate(100, sample_gnp(10, 1/2), simplify = FALSE) %>%
@@ -261,16 +269,22 @@ neighbors <- function(graph, v, mode = c("out", "in", "all", "total")) {
     mode <- igraph.match.arg(mode)
     mode <- switch(mode, "out"=1, "in"=2, "all"=3, "total"=3)
   }
+  v <- as.igraph.vs(graph, v)
+  if (length(v) == 0) {
+    stop("No vertex was specified")
+  }
   on.exit( .Call(C_R_igraph_finalizer) )
-  res <- .Call(C_R_igraph_neighbors, graph, as.igraph.vs(graph, v)-1,
-               as.numeric(mode))
-  V(graph)[res + 1]
+  res <- .Call(C_R_igraph_neighbors, graph, v-1, as.numeric(mode)) + 1L
+
+  if (igraph_opt("return.vs.es")) res <- create_vs(graph, res)
+
+  res
 }
 
 #' Incident edges of a vertex in a graph
 #'
 #' @param graph The input graph.
-#' @param v The vertex of which the indicent edges are queried.
+#' @param v The vertex of which the incident edges are queried.
 #' @param mode Whether to query outgoing (\sQuote{out}), incoming
 #'   (\sQuote{in}) edges, or both types (\sQuote{all}). This is
 #'   ignored for undirected graphs.
@@ -295,9 +309,12 @@ incident <- function(graph, v, mode=c("all", "out", "in", "total")) {
   } else {
     mode=1
   }
+  v <- as.igraph.vs(graph, v)
+  if (length(v) == 0) {
+    stop("No vertex was specified")
+  }
   on.exit( .Call(C_R_igraph_finalizer) )
-  res <- .Call(C_R_igraph_incident, graph, as.igraph.vs(graph, v)-1,
-               as.numeric(mode)) + 1L
+  res <- .Call(C_R_igraph_incident, graph, v-1, as.numeric(mode)) + 1L
 
   if (igraph_opt("return.vs.es")) res <- create_es(graph, res)
 
@@ -391,7 +408,7 @@ get.edges <- function(graph, es) {
 #' vertices.
 #' 
 #' @param graph The input graph.
-#' @param vp The indicent vertices, given as vertex ids or symbolic vertex
+#' @param vp The incident vertices, given as vertex ids or symbolic vertex
 #' names. They are interpreted pairwise, i.e. the first and second are used for
 #' the first edge, the third and fourth for the second, etc.
 #' @param directed Logical scalar, whether to consider edge directions in
@@ -418,7 +435,22 @@ get.edges <- function(graph, es) {
 #' 
 #' ## non-existant edge
 #' get.edge.ids(g, c(2,1, 1,4, 5,4))
+#'
+#' ## multiple edges
+#' ## multi = FALSE, a single edge id is returned,
+#' ## as many times as corresponding pairs in the vertex series.
+#' g <-  make_graph(rep(c(1,2), 5))
+#' eis <- get.edge.ids(g, c(1,2, 1,2), multi=FALSE)
+#' eis
+#' E(g)[eis]
 #' 
+#' ## multi = TRUE, as many different edges, if any,
+#' ## are returned as pairs in the vertex series.
+#' eim <- get.edge.ids(g, c(1,2, 1,2, 1,2), multi=TRUE)
+#' eim
+#' E(g)[eim]
+#' 
+
 get.edge.ids <- function(graph, vp, directed=TRUE, error=FALSE, multi=FALSE) {
   if (!is_igraph(graph)) {
     stop("Not a graph object")
@@ -431,6 +463,8 @@ get.edge.ids <- function(graph, vp, directed=TRUE, error=FALSE, multi=FALSE) {
 
 #' Order (number of vertices) of a graph
 #'
+#' \code{vcount} is an alias of this function.
+#'
 #' @param graph The graph
 #' @return Number of vertices, numeric scalar.
 #'
@@ -441,6 +475,7 @@ get.edge.ids <- function(graph, vp, directed=TRUE, error=FALSE, multi=FALSE) {
 #' @examples
 #' g <- make_ring(10)
 #' gorder(g)
+#' vcount(g)
 
 gorder <- gorder
 
@@ -475,7 +510,8 @@ adjacent_vertices <- function(graph, v,
   res <- .Call(C_R_igraph_adjacent_vertices, graph, vv, mode)
 
   if (igraph_opt("return.vs.es")) {
-    res <- lapply(res, function(x) create_vs(graph, x + 1))
+    res <- lapply(res, `+`, 1)
+    res <- lapply(res, unsafe_create_vs, graph = graph, verts = V(graph))
   }
 
   if (is_named(graph)) names(res) <- V(graph)$name[vv + 1]
@@ -514,7 +550,8 @@ incident_edges <- function(graph, v,
   res <- .Call(C_R_igraph_incident_edges, graph, vv, mode)
 
   if (igraph_opt("return.vs.es")) {
-    res <- lapply(res, function(x) create_es(graph, x + 1))
+    res <- lapply(res, `+`, 1)
+    res <- lapply(res, unsafe_create_es, graph = graph, es = E(graph))
   }
 
   if (is_named(graph)) names(res) <- V(graph)$name[vv + 1]
