@@ -22,23 +22,7 @@
 
 .onAttach <- function(library, pkg) {
     ## we can't do this in .onLoad
-    unlockBinding(".igraph.pars", asNamespace("igraph"))
     unlockBinding(".igraph.pb", asNamespace("igraph"))
     invisible()
 }
 
-.onLoad <- function(libname, pkgname) {
-  library.dynam("igraph", pkgname, libname, local=FALSE);
-  .Call("R_igraph_init", FALSE, FALSE, PACKAGE="igraph")
-}
-
-.onUnload <- function(libpath) {
-  library.dynam.unload("igraph", libpath)
-}
-
-.Call <- function(.NAME, ...) {
-  if (.NAME != "R_igraph_finalizer") {
-    base::.Call("R_igraph_check_finally_stack", PACKAGE="igraph")
-  }
-  base::.Call(.NAME, ...)
-}
