@@ -125,9 +125,9 @@ plot.igraph <- function(x,
   curved             <- params("edge", "curved")
   if (is.function(curved)) { curved <- curved(graph) }
   
-  layout             <- params("plot", "layout")
+  layout             <- i.postprocess.layout(params("plot", "layout"))
   margin             <- params("plot", "margin")
-  margin <- rep(margin, length=4)
+  margin <- rep(margin, length.out=4)
   rescale            <- params("plot", "rescale")
   asp                <- params("plot", "asp")
   frame              <- params("plot", "frame")
@@ -164,18 +164,22 @@ plot.igraph <- function(x,
   if (!is.list(mark.groups) && is.numeric(mark.groups)) {
     mark.groups <- list(mark.groups)
   }
+  if (inherits(mark.groups, "communities")) {
+    mark.groups <- communities(mark.groups)
+  }
 
-  mark.shape  <- rep(mark.shape,  length=length(mark.groups))
-  mark.border <- rep(mark.border, length=length(mark.groups))
-  mark.col    <- rep(mark.col,    length=length(mark.groups))
-  mark.expand <- rep(mark.expand, length=length(mark.groups))
+  mark.shape  <- rep(mark.shape,  length.out=length(mark.groups))
+  mark.border <- rep(mark.border, length.out=length(mark.groups))
+  mark.col    <- rep(mark.col,    length.out=length(mark.groups))
+  mark.expand <- rep(mark.expand, length.out=length(mark.groups))
   
   for (g in seq_along(mark.groups)) {
-    v <- V(graph)[mark.groups[[g]]]
+    .members <- mark.groups[[g]]
+    v <- V(graph)[.members]
     if (length(vertex.size)==1) {
       vs <- vertex.size
     } else {
-      vs <- rep(vertex.size, length=vcount(graph))[v]
+      vs <- rep(vertex.size, length.out=vcount(graph))[v]
     }
     igraph.polygon(layout[v,,drop=FALSE],
                    vertex.size=vs,
@@ -218,14 +222,14 @@ plot.igraph <- function(x,
                                             params=params, end="both")
   } else {
     ## different vertex shapes, do it by "endpoint"
-    shape <- rep(shape, length=vcount(graph))
+    shape <- rep(shape, length.out=vcount(graph))
     ec <- edge.coords
-    ec[,1:2] <- t(sapply(seq(length=nrow(el)), function(x) {
+    ec[,1:2] <- t(sapply(seq(length.out=nrow(el)), function(x) {
       .igraph.shapes[[ shape[el[x,1]] ]]$clip(edge.coords[x,,drop=FALSE],
                                               el[x,,drop=FALSE],
                                               params=params, end="from")
     }))
-    ec[,3:4] <- t(sapply(seq(length=nrow(el)), function(x) {
+    ec[,3:4] <- t(sapply(seq(length.out=nrow(el)), function(x) {
       .igraph.shapes[[ shape[el[x,2]] ]]$clip(edge.coords[x,,drop=FALSE],
                                               el[x,,drop=FALSE],
                                               params=params, end="to")
@@ -288,7 +292,7 @@ plot.igraph <- function(x,
       cp[,1] <- cx+r*cos(phi)
       cp[,2] <- cy+r*sin(phi)
 
-      if (is.na(width)) { width <- 0 }
+      if (is.na(width)) { width <- 1 }
 
       plot.bezier(cp, 50, color, width, arr=arr, lty=lty, arrow.size=arrow.size, arr.w=arr.w)
 
@@ -352,7 +356,7 @@ plot.igraph <- function(x,
     } else {
       ## different kinds of arrows drawn separately as 'arrows' cannot
       ## handle a vector as the 'code' argument
-      curved <- rep(curved, length=ecount(graph))[nonloops.e]
+      curved <- rep(curved, length.out=ecount(graph))[nonloops.e]
       lc.x <- lc.y <- numeric(length(curved))
       for (code in 0:3) {
         valid <- arrow.mode==code
@@ -382,7 +386,7 @@ plot.igraph <- function(x,
     if (length(unique(shape)) == 1) {
       .igraph.shapes[[ shape[1] ]]$plot(layout, params=params)
     } else {
-      sapply(seq(length=vcount(graph)), function(x) {
+      sapply(seq(length.out=vcount(graph)), function(x) {
         .igraph.shapes[[ shape[x] ]]$plot(layout[x,,drop=FALSE], v=x,
                                           params=params)
       })
@@ -651,7 +655,7 @@ rglplot.igraph <- function(x, ...) {
   rgl::par3d(skipRedraw=TRUE)
 
   # edges first
-  for (i in seq(length=nrow(el))) {
+  for (i in seq(length.out=nrow(el))) {
     from <- el[i,1]
     to   <- el[i,2]
     v1 <- layout[from,]
@@ -736,7 +740,7 @@ function (x1, y1, x2, y2,
   uin <- if (is.R()) 
     1/xyinch()
   else par("uin")
-  x <- sqrt(seq(0, cin^2, length = floor(35 * cin) + 2))
+  x <- sqrt(seq(0, cin^2, length.out = floor(35 * cin) + 2))
   delta <-  sqrt(h.lwd)*par("cin")[2]*0.005      ## has been 0.05
   x.arr <- c(-rev(x), -x)
   wx2 <- width * x^2
@@ -788,9 +792,9 @@ function (x1, y1, x2, y2,
     midy <- (y1+y2)/2  
     spx <- midx - lambda * 1/2 * (c.y2-c.y1)
     spy <- midy + lambda * 1/2 * (c.x2-c.x1)
-    sh.col <- rep(sh.col, length=length(c.x1))
-    sh.lty <- rep(sh.lty, length=length(c.x1))
-    sh.lwd <- rep(sh.lwd, length=length(c.x1))
+    sh.col <- rep(sh.col, length.out=length(c.x1))
+    sh.lty <- rep(sh.lty, length.out=length(c.x1))
+    sh.lwd <- rep(sh.lwd, length.out=length(c.x1))
     lc.x <- lc.y <- numeric(length(c.x1))
 
     for (i in seq_len(length(c.x1))) {
