@@ -213,7 +213,7 @@
 #' add_shape("triangle", clip=shapes("circle")$clip,
 #'                  plot=mytriangle)
 #' plot(g, vertex.shape="triangle", vertex.color=rainbow(vcount(g)),
-#'      vertex.size=seq(10,20,length=vcount(g)))
+#'      vertex.size=seq(10,20,length.out=vcount(g)))
 #'
 #' #################################################################
 #' # generic star vertex shape, with a parameter for number of rays
@@ -242,72 +242,10 @@
 #' add_shape("star", clip=shape_noclip,
 #'                  plot=mystar, parameters=list(vertex.norays=5))
 #' plot(g, vertex.shape="star", vertex.color=rainbow(vcount(g)),
-#'      vertex.size=seq(10,20,length=vcount(g)))
+#'      vertex.size=seq(10,20,length.out=vcount(g)))
 #' plot(g, vertex.shape="star", vertex.color=rainbow(vcount(g)),
-#'      vertex.size=seq(10,20,length=vcount(g)),
-#'      vertex.norays=rep(4:8, length=vcount(g)))
-#'
-#' #################################################################
-#' # Pictures as vertices.
-#' # Similar musicians from last.fm, we start from an artist and
-#' # will query two levels. We will use the XML, png and jpeg packages
-#' # for this, so these must be available. Otherwise the example is
-#' # skipped
-#'
-#' loadIfYouCan <- function(pkg) suppressWarnings(do.call(require, list(pkg)))
-#'
-#' if (loadIfYouCan("XML") && loadIfYouCan("png") &&
-#'     loadIfYouCan("jpeg")) {
-#'   url <- paste(sep="",
-#'                'http://ws.audioscrobbler.com/',
-#'                '2.0/?method=artist.getinfo&artist=%s',
-#'                '&api_key=1784468ada3f544faf9172ee8b99fca3')
-#'   getartist <- function(artist) {
-#'     cat("Downloading from last.fm. ... ")
-#'     txt <- readLines(sprintf(url, URLencode(artist)))
-#'     xml <- xmlTreeParse(txt, useInternal=TRUE)
-#'     img <- xpathSApply(xml, "/lfm/artist/image[@@size='medium'][1]",
-#'                        xmlValue)
-#'     if (img != "") {
-#'       con <- url(img, open="rb")
-#'       bin <- readBin(con, what="raw", n=10^6)
-#'       close(con)
-#'       if (grepl("\\\\.png$", img)) {
-#'         rast <- readPNG(bin, native=TRUE)
-#'       } else if (grepl("\\\\.jpe?g$", img)) {
-#'         rast <- readJPEG(bin, native=TRUE)
-#'       } else {
-#'         rast <- as.raster(matrix())
-#'       }
-#'     } else {
-#'       rast <- as.raster(numeric())
-#'     }
-#'     sim <- xpathSApply(xml, "/lfm/artist/similar/artist/name", xmlValue)
-#'     cat("done.\\n")
-#'     list(name=artist, image=rast, similar=sim)
-#'   }
-#'
-#'   ego <- getartist("Placebo")
-#'   similar <- lapply(ego$similar, getartist)
-#'
-#'   edges1 <- cbind(ego$name, ego$similar)
-#'   edges2 <- lapply(similar, function(x) cbind(x$name, x$similar))
-#'   edges3 <- rbind(edges1, do.call(rbind, edges2))
-#'   edges <- edges3[ edges3[,1] %in% c(ego$name, ego$similar) &
-#'                    edges3[,2] %in% c(ego$name, ego$similar), ]
-#'
-#'   musnet <- simplify(graph_from_data_frame(edges, dir=FALSE,
-#'                      vertices=data.frame(name=c(ego$name, ego$similar))))
-#'   print_all(musnet)
-#'
-#'   V(musnet)$raster <- c(list(ego$image), lapply(similar, "[[", "image"))
-#'   plot(musnet, layout=layout_as_star, vertex.shape="raster",
-#'        vertex.label=V(musnet)$name, margin=.2,
-#'        vertex.size=50, vertex.size2=50,
-#'        vertex.label.dist=2, vertex.label.degree=0)
-#' } else {
-#'   message("You need the `XML', `png' and `jpeg' packages to run this")
-#' }
+#'      vertex.size=seq(10,20,length.out=vcount(g)),
+#'      vertex.norays=rep(4:8, length.out=vcount(g)))
 
 shapes <- function(shape=NULL) {
   if (is.null(shape)) {
@@ -422,14 +360,31 @@ add_shape <- function(shape, clip=shape_noclip,
   if (length(vertex.frame.color) != 1 && !is.null(v)) {
     vertex.frame.color <- vertex.frame.color[v]
   }
+  vertex.frame.width <- params("vertex", "frame.width")
+  if (length(vertex.frame.width) != 1 && !is.null(v)) {
+    vertex.frame.width <- vertex.frame.width[v]
+  }
   vertex.size        <- 1/200 * params("vertex", "size")
   if (length(vertex.size) != 1 && !is.null(v)) {
     vertex.size <- vertex.size[v]
   }
-  vertex.size <- rep(vertex.size, length=nrow(coords))
-  
-  symbols(x=coords[,1], y=coords[,2], bg=vertex.color, fg=vertex.frame.color,
-          circles=vertex.size, add=TRUE, inches=FALSE)
+  vertex.size <- rep(vertex.size, length.out=nrow(coords))
+
+  # Handle vertex.frame.width <= 0 by hiding the border
+  vertex.frame.color[vertex.frame.width <= 0] <- NA
+  vertex.frame.width[vertex.frame.width <= 0] <- 1
+
+  if (length(vertex.frame.width) ==1) {
+    symbols(x=coords[,1], y=coords[,2], bg=vertex.color, fg=vertex.frame.color,
+          circles=vertex.size, lwd=vertex.frame.width, add=TRUE, inches=FALSE)
+  } else {
+    mapply(coords[,1], coords[,2], vertex.color, vertex.frame.color,
+           vertex.size, vertex.frame.width,
+           FUN=function(x, y, bg, fg, size, lwd) {
+               symbols(x=x, y=y, bg=bg, fg=fg, lwd=lwd,
+                       circles=size, add=TRUE, inches=FALSE)
+           })
+  }
 }
 
 .igraph.shape.square.clip <- function(coords, el, params,
@@ -461,7 +416,7 @@ add_shape <- function(shape, clip=shape_noclip,
                (l[,5]-x0)^2 + (l[,6]-y0)^2,
                (l[,7]-x0)^2 + (l[,8]-y0)^2)
     
-    t(sapply(seq(length=nrow(l)), function(x) {
+    t(sapply(seq(length.out=nrow(l)), function(x) {
       d[x,][!v[x,]] <- Inf
       m <- which.min(d[x,])
       l[x, c(m*2-1, m*2)]
@@ -505,14 +460,31 @@ add_shape <- function(shape, clip=shape_noclip,
   if (length(vertex.frame.color) != 1 && !is.null(v)) {
     vertex.frame.color <- vertex.frame.color[v]
   }
+  vertex.frame.width <- params("vertex", "frame.width")
+  if (length(vertex.frame.width) != 1 && !is.null(v)) {
+    vertex.frame.width <- vertex.frame.width[v]
+  }
   vertex.size        <- 1/200 * params("vertex", "size")
   if (length(vertex.size) != 1 && !is.null(v)) {
     vertex.size <- vertex.size[v]
   }
-  vertex.size <- rep(vertex.size, length=nrow(coords))
+  vertex.size <- rep(vertex.size, length.out=nrow(coords))
   
-  symbols(x=coords[,1], y=coords[,2], bg=vertex.color, fg=vertex.frame.color,
-          squares=2*vertex.size, add=TRUE, inches=FALSE)
+  # Handle vertex.frame.width <= 0 by hiding the border
+  vertex.frame.color[vertex.frame.width <= 0] <- NA
+  vertex.frame.width[vertex.frame.width <= 0] <- 1
+
+  if (length(vertex.frame.width) ==1) {
+    symbols(x=coords[,1], y=coords[,2], bg=vertex.color, fg=vertex.frame.color,
+          squares=2*vertex.size, lwd=vertex.frame.width, add=TRUE, inches=FALSE)
+  } else {
+    mapply(coords[,1], coords[,2], vertex.color, vertex.frame.color,
+           vertex.size, vertex.frame.width,
+           FUN=function(x, y, bg, fg, size, lwd) {
+               symbols(x=x, y=y, bg=bg, fg=fg, lwd=lwd,
+                       squares=2*size, add=TRUE, inches=FALSE)
+           })
+  }
 }  
 
 .igraph.shape.csquare.clip <- function(coords, el, params,
@@ -536,7 +508,7 @@ add_shape <- function(shape, clip=shape_noclip,
                (l[,5]-x0)^2 + (l[,6]-y0)^2,
                (l[,7]-x0)^2 + (l[,8]-y0)^2)
     
-    t(sapply(seq(length=nrow(l)), function(x) {
+    t(sapply(seq(length.out=nrow(l)), function(x) {
       m <- which.min(d[x,])
       l[x, c(m*2-1, m*2)]
     }))
@@ -600,7 +572,7 @@ add_shape <- function(shape, clip=shape_noclip,
                (l[,5]-x0)^2 + (l[,6]-y0)^2,
                (l[,7]-x0)^2 + (l[,8]-y0)^2)
     
-    t(sapply(seq(length=nrow(l)), function(x) {
+    t(sapply(seq(length.out=nrow(l)), function(x) {
       d[x,][!v[x,]] <- Inf
       m <- which.min(d[x,])
       l[x, c(m*2-1, m*2)]
@@ -654,19 +626,36 @@ add_shape <- function(shape, clip=shape_noclip,
   if (length(vertex.frame.color) != 1 && !is.null(v)) {
     vertex.frame.color <- vertex.frame.color[v]
   }
+  vertex.frame.width <- params("vertex", "frame.width")
+  if (length(vertex.frame.width) != 1 && !is.null(v)) {
+    vertex.frame.width <- vertex.frame.width[v]
+  }
   vertex.size        <- 1/200 * params("vertex", "size")
   if (length(vertex.size) != 1 && !is.null(v)) {
     vertex.size <- vertex.size[v]
   }
-  vertex.size <- rep(vertex.size, length=nrow(coords))   
+  vertex.size <- rep(vertex.size, length.out=nrow(coords))   
   vertex.size2       <- 1/200 * params("vertex", "size2")
   if (length(vertex.size2) != 1 && !is.null(v)) {
     vertex.size2 <- vertex.size2[v]
   }
   vertex.size <- cbind(vertex.size, vertex.size2)
   
-  symbols(x=coords[,1], y=coords[,2], bg=vertex.color, fg=vertex.frame.color,
-          rectangles=2*vertex.size, add=TRUE, inches=FALSE)
+  # Handle vertex.frame.width <= 0 by hiding the border
+  vertex.frame.color[vertex.frame.width <= 0] <- NA
+  vertex.frame.width[vertex.frame.width <= 0] <- 1
+
+  if (length(vertex.frame.width) ==1) {
+    symbols(x=coords[,1], y=coords[,2], bg=vertex.color, fg=vertex.frame.color,
+          rectangles=2*vertex.size, lwd=vertex.frame.width, add=TRUE, inches=FALSE)
+  } else {
+    mapply(coords[,1], coords[,2], vertex.color, vertex.frame.color,
+           vertex.size[,1], vertex.size[,2], vertex.frame.width,
+           FUN=function(x, y, bg, fg, size, size2 , lwd) {
+               symbols(x=x, y=y, bg=bg, fg=fg, lwd=lwd,
+                       rectangles=2*cbind(size,size2), add=TRUE, inches=FALSE)
+           })
+  }
 }
 
 .igraph.shape.crectangle.clip <- function(coords, el, params,
@@ -691,7 +680,7 @@ add_shape <- function(shape, clip=shape_noclip,
                (l[,5]-x0)^2 + (l[,6]-y0)^2,
                (l[,7]-x0)^2 + (l[,8]-y0)^2)
       
-    t(sapply(seq(length=nrow(l)), function(x) {
+    t(sapply(seq(length.out=nrow(l)), function(x) {
       m <- which.min(d[x,])
       l[x, c(m*2-1, m*2)]
     }))
@@ -751,7 +740,7 @@ add_shape <- function(shape, clip=shape_noclip,
     d <- cbind((l[,1]-x0)^2 + (l[,2]-y0)^2,
                (l[,3]-x0)^2 + (l[,4]-y0)^2)
     
-    t(sapply(seq(length=nrow(l)), function(x) {
+    t(sapply(seq(length.out=nrow(l)), function(x) {
       m <- which.min(d[x,])
       l[x, c(m*2-1, m*2)]
     }))
@@ -894,7 +883,7 @@ mypie <- function(x, y, values, radius, edges=200, col=NULL, angle=45,
   }
   vertex.color       <- getparam("color")
   vertex.frame.color <- getparam("frame.color")
-  vertex.size        <- rep(1/200 * getparam("size"), length=nrow(coords))
+  vertex.size        <- rep(1/200 * getparam("size"), length.out=nrow(coords))
   vertex.pie         <- getparam("pie")
   vertex.pie.color   <- getparam("pie.color")
   vertex.pie.angle   <- getparam("pie.angle")
@@ -935,8 +924,8 @@ mypie <- function(x, y, values, radius, edges=200, col=NULL, angle=45,
     }
     p
   }
-  vertex.color       <- rep(getparam("color"), length=nrow(coords))
-  vertex.size        <- rep(1/200 * getparam("size"), length=nrow(coords))
+  vertex.color       <- rep(getparam("color"), length.out=nrow(coords))
+  vertex.size        <- rep(1/200 * getparam("size"), length.out=nrow(coords))
 
   ## Need to create a separate image for every different vertex color
   allcols <- unique(vertex.color)
@@ -971,8 +960,8 @@ mypie <- function(x, y, values, radius, edges=200, col=NULL, angle=45,
     p
   }
 
-  size   <- rep(1/200 * getparam("size"), length=nrow(coords))
-  size2  <- rep(1/200 * getparam("size2"), length=nrow(coords))
+  size   <- rep(1/200 * getparam("size"), length.out=nrow(coords))
+  size2  <- rep(1/200 * getparam("size2"), length.out=nrow(coords))
   raster <- getparam("raster")
 
   for (i in seq_len(nrow(coords))) {
