@@ -1,6 +1,10 @@
 
 #' Random walk on a graph
 #'
+#' \code{random_walk} performs a random walk on the graph and returns the
+#' vertices that the random walk passed through. \code{random_edge_walk}
+#' is the same but returns the edges that that random walk passed through.
+#'
 #' Do a random walk. From the given start vertex, take the given number of
 #' steps, choosing an edge from the actual vertex uniformly randomly. Edge
 #' directions are observed in directed graphs (see the \code{mode} argument
@@ -9,12 +13,20 @@
 #' @param graph The input graph, might be undirected or directed.
 #' @param start The start vertex.
 #' @param steps The number of steps to make.
+#' @param weights The edge weights. Larger edge weights increase the
+#'   probability that an edge is selected by the random walker. In other
+#'   words, larger edge weights correspond to stronger connections. The
+#'   \sQuote{weight} edge attribute is used if present. Supply
+#'   \sQuote{\code{NA}} here if you want to ignore the \sQuote{weight} edge
+#'   attribute.
 #' @param mode How to follow directed edges. \code{"out"} steps along the
 #'   edge direction, \code{"in"} is opposite to that. \code{"all"} ignores
 #'   edge directions. This argument is ignored for undirected graphs.
 #' @param stuck What to do if the random walk gets stuck. \code{"return"}
 #'   returns the partial walk, \code{"error"} raises an error.
-#' @return A vertex sequence containing the vertices along the walk.
+#' @return For \code{random_walk}, a vertex sequence containing the vertices
+#'   along the walk. For \code{random_edge_walk}, an edge sequence containing
+#'   the edges along the walk.
 #' @export
 #' @examples
 #' ## Stationary distribution of a Markov chain
@@ -30,23 +42,7 @@
 #'
 #' ## But these are (almost) the same
 #' cor(table(w), pg)
+random_walk <- random_walk
 
-random_walk <- function(graph, start, steps, mode = c("out", "in", "all"),
-                        stuck = c("return", "error")) {
-  ## Argument checks
-  if (!is_igraph(graph)) stop("Not a graph object")
-  start <- as.igraph.vs(graph, start)
-  mode <- switch(igraph.match.arg(mode), "out" = 1, "in" = 2, "all" = 3,
-                 "total" = 3)
-  steps <- as.integer(steps)
-  stuck <- switch(igraph.match.arg(stuck), "error" = 0L, "return" = 1L)
-
-  on.exit( .Call(C_R_igraph_finalizer) )
-
-  ## Function call
-  res <- .Call(C_R_igraph_random_walk, graph, start - 1, mode, steps, stuck)
-  if (igraph_opt("return.vs.es")) {
-    res <- create_vs(graph, res)
-  }
-  res
-}
+#' @rdname random_walk
+random_edge_walk <- random_edge_walk
