@@ -1,9 +1,9 @@
 
-context("Bug 1073800")
+context("Bug 1073800 from Launchpad")
 
 test_that("Largest cliques is correct", {
   library(igraph)
-  unvs <- function(x) lapply(x, as.vector)
+  unvs <- function(x) lapply(x, . %>% as.vector %>% sort)
   adj <- matrix(1, nrow=11, ncol=11) - diag(11)
   g <- graph_from_adjacency_matrix(adj)
   lc <- suppressWarnings(largest_cliques(g))
