@@ -8,9 +8,13 @@ test_that("dominator_tree works", {
                  K-+I:R, L-+H)
   dtree <- dominator_tree(g, root="R")
 
-  dtree$dom <- V(g)$name[ as.vector(dtree$dom) ]
+  # This is awkward; dtree$dom contains -1 for the root and normal vertex indices
+  # for the rest, and we want to map them to names. This seemed to be the cleanest
+  # way, but it is not nearly as user-friendly as it should be
+  names <- c("$root", V(g)$name)
+  dtree$dom <- names[ifelse(dtree$dom < 0, 1, dtree$dom + 1)]
   dtree$leftout <- V(g)$name[ dtree$leftout ]
-  expect_that(dtree$dom, equals(c("R", "R", "R", "R", "R", "C", "C",
+  expect_that(dtree$dom, equals(c("$root", "R", "R", "R", "R", "R", "C", "C",
                                   "D", "R", "R", "G", "R")))
   expect_that(dtree$leftout, equals(character()))
   expect_that(as_edgelist(dtree$domtree),
