@@ -6,5 +6,5 @@ test_that("ends works", {
   g <- sample_gnp(100, 3/100)
   edges <- unlist(lapply(seq_len(ecount(g)), ends, graph=g))
   g2 <- graph(edges, dir=FALSE, n=vcount(g))
-  expect_that(graph.isomorphic(g, g2), is_true())
+  expect_true(graph.isomorphic(g, g2))
 })
