@@ -6,7 +6,7 @@ test_that("as_incidence_matrix works", {
   library(igraph)
 
   ## Dense
-  I <- matrix(sample(0:1, 35, replace=TRUE, prob=c(3,1)), nc=5)
+  I <- matrix(sample(0:1, 35, replace=TRUE, prob=c(3,1)), ncol=5)
   g <- graph_from_incidence_matrix(I)
   I2 <- as_incidence_matrix(g)
   expect_that(I, is_equivalent_to(I2))
