@@ -56,7 +56,7 @@ threshold.net <- function(graph, level) {
 graphlets.old <- function(graph) {
 
   if (!is_weighted(graph)) { stop("Graph not weighted") }
-  if (min(E(graph)$weight) <= 0 || !any(is.finite(E(graph)$weight))) {
+  if (min(E(graph)$weight) <= 0 || any(!is.finite(E(graph)$weight))) {
     stop("Edge weights must be non-negative and finite")
   }
 
@@ -98,7 +98,7 @@ test_that("Graphlets work for a bigger graph", {
 graphlets.project.old <- function(graph, cliques, iter, Mu=NULL) {
 
   if (!is_weighted(graph)) { stop("Graph not weighted") }
-  if (min(E(graph)$weight) <= 0 || !any(is.finite(E(graph)$weight))) {
+  if (min(E(graph)$weight) <= 0 || any(!is.finite(E(graph)$weight))) {
     stop("Edge weights must be non-negative and finite")
   }
   if (length(iter) != 1 || !is.numeric(iter) ||
@@ -150,7 +150,7 @@ graphlets.project.old <- function(graph, cliques, iter, Mu=NULL) {
   }
 
   ## Sort the cliques according to their weights
-  Smb <- sort(Mu, decreasing=TRUE, index=TRUE)
+  Smb <- sort(Mu, decreasing=TRUE, index.return=TRUE)
   list(cliques=clf[Smb$ix], Mu=Mu[Smb$ix])
 }
 
