@@ -11,7 +11,7 @@ test_that("SGM works", {
   
   g1 <- erdos.renyi.game(vc, .5)
   randperm <- c(1:nos, nos + sample(vc-nos))
-  g2 <- sample_correlated_gnp(g1, corr=.7, p=g1$p, perm=randperm)
+  g2 <- sample_correlated_gnp(g1, corr=.7, p=g1$p, permutation=randperm)
   P  <-match_vertices (g1[], g2[], m=nos, start=matrix(1/(vc-nos), vc-nos, vc-nos),
             iteration=20)
 
@@ -28,7 +28,7 @@ test_that("SGM works", {
 
   g1 <- erdos.renyi.game(vc, .1);
   perm <- c(1:nos, sample(vc-nos)+nos)
-  g2 <- sample_correlated_gnp(g1, corr=1, p=g1$p, perm=perm)
+  g2 <- sample_correlated_gnp(g1, corr=1, p=g1$p, permutation=perm)
 
   P <- match_vertices(g1[], g2[], m=nos, start=matrix(1/(vc-nos), vc-nos, vc-nos),
            iteration=20)
